| geom_pareto_line | R Documentation |
geom_pareto_line() computes cumulative totals from absolute values sorted by
decreasing magnitude and draws the resulting path.
geom_pareto_point() computes cumulative totals from absolute values sorted
by decreasing magnitude and draws the resulting points.
geom_pareto_line(
mapping = NULL,
data = NULL,
stat = "pareto_line",
position = "identity",
...,
cumulative = c("raw", "proportion"),
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
geom_pareto_point(
mapping = NULL,
data = NULL,
stat = "pareto_line",
position = "identity",
...,
cumulative = c("raw", "proportion"),
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
stat_pareto_line(
mapping = NULL,
data = NULL,
geom = "path",
position = "identity",
...,
cumulative = c("raw", "proportion"),
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
stat |
The statistical transformation to use on the layer. |
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
... |
Other arguments passed on to
|
cumulative |
|
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
geom |
The geometric object to use display the data. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.