| geom_qqhn | R Documentation |
geom_qqhn() draws a half-normal QQ plot using absolute sample values.
Theoretical quantiles are from the half-normal distribution, i.e.
qnorm((p + 1) / 2).
geom_qqhn(
mapping = NULL,
data = NULL,
stat = "qqhn",
position = "identity",
...,
abs_sample = TRUE,
label_n = 0,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
stat_qqhn(
mapping = NULL,
data = NULL,
geom = "point",
position = "identity",
...,
abs_sample = TRUE,
label_n = 0,
labels_var = NULL,
output = c("all", "points", "labels"),
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
stat |
The statistical transformation to use on the layer. |
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
... |
Other arguments passed on to
|
abs_sample |
Should the sample be converted to absolute values. Defaults
to |
label_n |
Number of largest points to label. These labeled points are
removed from the point layer and drawn as text labels. Label text is taken
from the |
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
geom |
The geometric object to use display the data. |
labels_var |
Internal parameter used to forward label-column mappings. |
output |
Internal parameter controlling whether |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.