| geom_qqhn_band | R Documentation |
geom_qqhn_band() adds a confidence envelope around the half-normal QQ
reference line. The envelope is built from order-statistic probabilities
mapped through half-normal quantiles and then transformed by the fitted QQHN
line.
geom_qqhn_band(
mapping = NULL,
data = NULL,
stat = "qqhn_band",
position = "identity",
...,
line.p = 0.25,
abs_sample = TRUE,
conf.level = 0.95,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
stat_qqhn_band(
mapping = NULL,
data = NULL,
geom = "ribbon",
position = "identity",
...,
line.p = 0.25,
abs_sample = TRUE,
conf.level = 0.95,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
stat |
The statistical transformation to use on the layer. |
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
... |
Other arguments passed on to
|
line.p |
A single probability |
abs_sample |
Should the sample be converted to absolute values. Defaults
to |
conf.level |
Confidence level for the envelope. |
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
geom |
The geometric object to use display the data. |
Use conf.level to control envelope coverage (for example 0.95); alpha
only controls ribbon transparency.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.