| geom_qqhn_line | R Documentation |
geom_qqhn_line() adds a reference line for a half-normal QQ plot.
It mirrors geom_qq_line() but uses half-normal theoretical quantiles.
geom_qqhn_line(
mapping = NULL,
data = NULL,
stat = "qqhn_line",
position = "identity",
...,
line.p = 0.25,
abs_sample = TRUE,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
stat_qqhn_line(
mapping = NULL,
data = NULL,
geom = "path",
position = "identity",
...,
line.p = 0.25,
abs_sample = TRUE,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
stat |
The statistical transformation to use on the layer. |
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
... |
Other arguments passed on to
|
line.p |
A single probability |
abs_sample |
Should the sample be converted to absolute values. Defaults
to |
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
geom |
The geometric object to use display the data. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.