| daniel_plot_hn | R Documentation |
Given a non-replicated model of a factorial plan, this function provides a half-normal plot of the effects of the model, labeling the main n effects.
daniel_plot_hn(model, label_n = 6, line.p = c(0, 0.4), ...)
model |
a linear model |
label_n |
plot the labels of the highest n values |
line.p |
vector of quantiles to use when fitting the Q-Q line, defaults defaults to 0.25 that corresponds to c(0.25, 0.75) on the full set of quantiles. If you pass a vector of two elements (first MUST be 0), then the line is fitted through the origin and up to 1 minus the second element quantile |
... |
further arguments to |
a half-normal plot (GGPlot2 object) with the effects of the model
gghalfnorm::gghalfnorm()
daniel_plot_hn(lm(Y~A*B*C*D, data=filtration))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.