Learn R Programming

adas.utils (version 1.4.0)

daniel_plot_hn: Daniel's plot (half-normal)

Description

Given a non-replicated model of a factorial plan, this function provides a half-normal plot of the effects of the model, labeling the main n effects.

Usage

daniel_plot_hn(model, label_n = 6, line.p = c(0, 0.4), ...)

Value

a half-normal plot (GGPlot2 object) with the effects of the model

Arguments

model

a linear model

label_n

plot the labels of the highest n values

line.p

vector of quantiles to use when fitting the Q-Q line, defaults defaults to 0.25 that corresponds to c(0.25, 0.75) on the full set of quantiles. If you pass a vector of two elements (first MUST be 0), then the line is fitted through the origin and up to 1 minus the second element quantile

...

further arguments to gghalfnorm::gghalfnorm()

See Also

gghalfnorm::gghalfnorm()

Examples

Run this code
daniel_plot_hn(lm(Y~A*B*C*D, data=filtration))

Run the code above in your browser using DataLab