a half-normal plot (GGPlot2 object) with the effects of the model
Arguments
model
a linear model
label_n
plot the labels of the highest n values
line.p
vector of quantiles to use when fitting the Q-Q line, defaults
defaults to 0.25 that corresponds to c(0.25, 0.75) on the full set of
quantiles. If you pass a vector of two elements (first MUST be 0), then the
line is fitted through the origin and up to 1 minus the second element quantile